'use strict';

var React = require('react');

function _arrayLikeToArray(r, a) {
  (null == a || a > r.length) && (a = r.length);
  for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e];
  return n;
}
function _arrayWithHoles(r) {
  if (Array.isArray(r)) return r;
}
function _iterableToArrayLimit(r, l) {
  var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"];
  if (null != t) {
    var e,
      n,
      i,
      u,
      a = [],
      f = true,
      o = false;
    try {
      if (i = (t = t.call(r)).next, 0 === l) ; else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0);
    } catch (r) {
      o = true, n = r;
    } finally {
      try {
        if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return;
      } finally {
        if (o) throw n;
      }
    }
    return a;
  }
}
function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}
function _slicedToArray(r, e) {
  return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest();
}
function _unsupportedIterableToArray(r, a) {
  if (r) {
    if ("string" == typeof r) return _arrayLikeToArray(r, a);
    var t = {}.toString.call(r).slice(8, -1);
    return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : undefined;
  }
}

var languages = {
	javascript: {
		keywords: {
			controlFlow: [
				"break",
				"case",
				"catch",
				"continue",
				"default",
				"do",
				"else",
				"finally",
				"for",
				"if",
				"return",
				"switch",
				"throw",
				"try",
				"while",
				"with"
			],
			declarations: [
				"class",
				"const",
				"function",
				"let",
				"var"
			],
			operators: [
				"delete",
				"instanceof",
				"new",
				"typeof",
				"void",
				"yield"
			],
			special: [
				"debugger",
				"export",
				"extends",
				"import",
				"super",
				"this"
			]
		},
		comments: {
			singleLine: "//",
			multiLine: [
				"/*",
				"*/"
			]
		},
		strings: {
			delimiters: [
				"\"",
				"'",
				"`"
			]
		},
		numbers: "\\b\\d+(\\.\\d+)?\\b",
		operators: [
			"+",
			"-",
			"*",
			"/",
			"%",
			"++",
			"--",
			"==",
			"!=",
			"===",
			"!==",
			">",
			"<",
			">=",
			"<=",
			"&&",
			"||",
			"!",
			"=",
			"+=",
			"-=",
			"*=",
			"/=",
			"%=",
			"=>"
		]
	},
	python: {
		keywords: {
			controlFlow: [
				"else",
				"elif",
				"if",
				"try",
				"except",
				"finally",
				"for",
				"while",
				"continue",
				"break"
			],
			declarations: [
				"def",
				"class",
				"lambda",
				"global",
				"nonlocal"
			],
			boolean: [
				"True",
				"False",
				"None"
			],
			operators: [
				"and",
				"or",
				"not",
				"is",
				"in"
			]
		},
		comments: {
			singleLine: "#"
		},
		strings: {
			delimiters: [
				"\"",
				"'",
				"'''",
				"\"\"\""
			]
		},
		numbers: "\\b\\d+(\\.\\d+)?\\b",
		operators: [
			"+",
			"-",
			"*",
			"/",
			"%",
			"//",
			"**",
			"==",
			"!=",
			">",
			"<",
			">=",
			"<=",
			"and",
			"or",
			"not",
			"is",
			"in"
		]
	},
	java: {
		keywords: {
			controlFlow: [
				"if",
				"else",
				"for",
				"while",
				"switch",
				"case",
				"default",
				"break",
				"continue",
				"return",
				"throw",
				"try",
				"catch",
				"finally"
			],
			declarations: [
				"class",
				"interface",
				"enum",
				"extends",
				"implements",
				"new",
				"import",
				"package"
			],
			modifiers: [
				"public",
				"protected",
				"private",
				"static",
				"final",
				"abstract",
				"synchronized",
				"volatile",
				"transient"
			],
			primitives: [
				"int",
				"long",
				"short",
				"byte",
				"float",
				"double",
				"char",
				"boolean",
				"void"
			]
		},
		comments: {
			singleLine: "//",
			multiLine: [
				"/*",
				"*/"
			]
		},
		strings: {
			delimiters: [
				"\"",
				"'"
			]
		},
		numbers: "\\b\\d+(\\.\\d+)?(f|d|F|D)?\\b",
		operators: [
			"+",
			"-",
			"*",
			"/",
			"%",
			"++",
			"--",
			"==",
			"!=",
			">",
			"<",
			">=",
			"<=",
			"&&",
			"||",
			"!",
			"=",
			"+=",
			"-=",
			"*=",
			"/=",
			"%=",
			"&",
			"|",
			"^",
			"~",
			"<<",
			">>",
			">>>"
		]
	},
	c: {
		keywords: {
			controlFlow: [
				"if",
				"else",
				"switch",
				"case",
				"default",
				"break",
				"continue",
				"return",
				"goto",
				"while",
				"do",
				"for"
			],
			declarations: [
				"auto",
				"extern",
				"register",
				"static",
				"typedef",
				"struct",
				"union",
				"enum"
			],
			types: [
				"void",
				"char",
				"short",
				"int",
				"long",
				"float",
				"double",
				"signed",
				"unsigned",
				"const",
				"volatile"
			],
			special: [
				"sizeof",
				"_Alignas",
				"_Alignof",
				"_Atomic",
				"_Bool",
				"_Complex",
				"_Generic",
				"_Imaginary",
				"_Noreturn",
				"_Static_assert",
				"_Thread_local"
			]
		},
		comments: {
			singleLine: "//",
			multiLine: [
				"/*",
				"*/"
			]
		},
		strings: {
			delimiters: [
				"\"",
				"'"
			]
		},
		numbers: "\\b\\d+(\\.\\d+)?(f|F|l|L)?\\b",
		operators: [
			"+",
			"-",
			"*",
			"/",
			"%",
			"++",
			"--",
			"==",
			"!=",
			">",
			"<",
			">=",
			"<=",
			"&&",
			"||",
			"!",
			"=",
			"+=",
			"-=",
			"*=",
			"/=",
			"%=",
			"&",
			"|",
			"^",
			"~",
			"<<",
			">>",
			"->"
		]
	},
	ruby: {
		keywords: {
			controlFlow: [
				"if",
				"elsif",
				"else",
				"unless",
				"while",
				"until",
				"for",
				"break",
				"next",
				"redo",
				"retry",
				"return",
				"yield",
				"rescue",
				"ensure"
			],
			declarations: [
				"def",
				"class",
				"module",
				"alias",
				"begin",
				"end"
			],
			constants: [
				"true",
				"false",
				"nil",
				"self",
				"super"
			]
		},
		comments: {
			singleLine: "#"
		},
		strings: {
			delimiters: [
				"\"",
				"'",
				"%q",
				"%Q"
			]
		},
		numbers: "\\b\\d+(\\.\\d+)?\\b",
		operators: [
			"+",
			"-",
			"*",
			"/",
			"%",
			"**",
			"==",
			"!=",
			"<",
			">",
			"<=",
			">=",
			"&&",
			"||",
			"!",
			"=",
			"+=",
			"-=",
			"*=",
			"/=",
			"%=",
			"..",
			"..."
		]
	}
};
var syntaxData = {
	languages: languages
};

const sheet = new CSSStyleSheet();sheet.replaceSync(":root .standard {\n  --bg-color: #2e3440;\n  --text-color: #d8dee9;\n  --keyword-controlFlow: #81a1c1;\n  --keyword-declarations: #b48ead;\n  --operator-color: #d08770;\n  --number-color: #a3be8c;\n  --string-color: #ebcb8b;\n  --comment-color: #616e88;\n  --identifier-color: #d8dee9;\n}\n\n:root .solarized-light {\n  --bg-color: #fdf6e3;\n  --text-color: #002b36;\n  --keyword-controlFlow: #b58900;\n  --keyword-declarations: #cb4b16;\n  --operator-color: #dc322f;\n  --number-color: #2aa198;\n  --string-color: #268bd2;\n  --comment-color: #859900;\n  --identifier-color: #002b36;\n}\n\n:root .gruvbox-dark {\n  --bg-color: #282828;\n  --text-color: #ebdbb2;\n  --keyword-controlFlow: #fb4934;\n  --keyword-declarations: #b8bb26;\n  --operator-color: #fe8019;\n  --number-color: #fabd2f;\n  --string-color: #83a598;\n  --comment-color: #928374;\n  --identifier-color: #ebdbb2;\n}\n\n:root .monokai {\n  --bg-color: #272822;\n  --text-color: #f8f8f2;\n  --keyword-controlFlow: #ff79c6;\n  --keyword-declarations: #a6e22e;\n  --operator-color: #f92672;\n  --number-color: #fd971f;\n  --string-color: #a6e22e;\n  --comment-color: #75715e;\n  --identifier-color: #f8f8f2;\n}\n\n:root .dracula {\n  --bg-color: #282a36;\n  --text-color: #f8f8f2;\n  --keyword-controlFlow: #ff79c6;\n  --keyword-declarations: #50fa7b;\n  --operator-color: #bd93f9;\n  --number-color: #ffb86c;\n  --string-color: #50fa7b;\n  --comment-color: #6272a4;\n  --identifier-color: #f8f8f2;\n}\n\n:root .atom-one-dark {\n  --bg-color: #282c34;\n  --text-color: #c9d1d9;\n  --keyword-controlFlow: #66d9ef;\n  --keyword-declarations: #98c379;\n  --operator-color: #c678dd;\n  --number-color: #f92672;\n  --string-color: #98c379;\n  --comment-color: #5c6370;\n  --identifier-color: #c9d1d9;\n}\n\n:root .solarized-dark {\n  --bg-color: #002b36;\n  --text-color: #839496;\n  --keyword-controlFlow: #b58900;\n  --keyword-declarations: #cb4b16;\n  --operator-color: #dc322f;\n  --number-color: #2aa198;\n  --string-color: #268bd2;\n  --comment-color: #586e75;\n  --identifier-color: #839496;\n}\n\n:root .vs-code-dark {\n  --bg-color: #1e1e1e;\n  --text-color: #d4d4d4;\n  --keyword-controlFlow: #007acc;\n  --keyword-declarations: #0097a7;\n  --operator-color: #c763d2;\n  --number-color: #cc6633;\n  --string-color: #9cdcfe;\n  --comment-color: #6a737d;\n  --identifier-color: #d4d4d4;\n}\n\n:root .github {\n  --bg-color: #f6f8fa;\n  --text-color: #24292e;\n  --keyword-controlFlow: #0366d6;\n  --keyword-declarations: #0098ca;\n  --operator-color: #d73a49;\n  --number-color: #0098ca;\n  --string-color: #032f62;\n  --comment-color: #959da5;\n  --identifier-color: #24292e;\n}\n\n:root .ayu-mirage {\n  --bg-color: #1f2330;\n  --text-color: #cdd6f4;\n  --keyword-controlFlow: #f44785;\n  --keyword-declarations: #a6e22e;\n  --operator-color: #61afef;\n  --number-color: #f99157;\n  --string-color: #a6e22e;\n  --comment-color: #7f848e;\n  --identifier-color: #cdd6f4;\n}\n\n:root .one-dark-pro {\n  --bg-color: #282c34;\n  --text-color: #c9d1d9;\n  --keyword-controlFlow: #569cd6;\n  --keyword-declarations: #98c379;\n  --operator-color: #c678dd;\n  --number-color: #f92672;\n  --string-color: #98c379;\n  --comment-color: #5c6370;\n  --identifier-color: #c9d1d9;\n}\n\n:root .nord {\n  --bg-color: #2e3440;\n  --text-color: #d8dee9;\n  --keyword-controlFlow: #81a1c1;\n  --keyword-declarations: #b48ead;\n  --operator-color: #d08770;\n  --number-color: #a3be8c;\n  --string-color: #ebcb8b;\n  --comment-color: #616e88;\n  --identifier-color: #d8dee9;\n}\n\n.syntax-highlighter {\n  background-color: var(--bg-color);\n  color: var(--text-color);\n  padding: 16px;\n  border-radius: 8px;\n  overflow-x: auto;\n  font-family: \"Fira Code\", monospace;\n  white-space: pre-wrap;\n  line-height: 1.5;\n  tab-size: 4;\n}\n\n.syntax-highlighter *,\n.token {\n  margin: 0;\n  padding: 0;\n  box-sizing: border-box;\n}\n\n.token.keyword-controlFlow,\n.token.keyword-declarations {\n  margin-right: 5px;\n}\n\n.token.keyword-controlFlow {\n  color: var(--keyword-controlFlow);\n}\n\n.token.keyword-declarations {\n  color: var(--keyword-declarations);\n}\n\n.token.operator {\n  color: var(--operator-color);\n}\n\n.token.number {\n  color: var(--number-color);\n}\n\n.token.string {\n  color: var(--string-color);\n}\n\n.token.comment {\n  color: var(--comment-color);\n  font-style: italic;\n}\n\n.token.identifier {\n  color: var(--identifier-color);\n}\n");

// Define the types for the JSON structure

// Load the JSON file as typed data
var syntaxDataTyped = syntaxData;

// Define the props for the component

var SyntaxHighlighter = function SyntaxHighlighter(_ref) {
  var code = _ref.code,
    language = _ref.language,
    theme = _ref.theme;
  var languageRules = syntaxDataTyped.languages[language];
  if (!languageRules) {
    return /*#__PURE__*/React.createElement("pre", null, code); // Fallback if the language is not found
  }

  // Tokenize the input code string
  var tokenize = function tokenize(code) {
    var tokenRegex = /(\".*?\"|'.*?'|`.*?`|\/\/.*?$|\/\*[\s\S]*?\*\/|[\w$]+|[+\-*/=%!&|^~<>?:;.,{}[\]()\s]|[^\s])/gm;
    return code.match(tokenRegex) || [];
  };

  // Determine the type of a token
  var getTokenType = function getTokenType(token) {
    var _languageRules$operat, _languageRules$string, _languageRules$commen, _languageRules$commen2;
    if (languageRules.keywords) {
      for (var _i = 0, _Object$entries = Object.entries(languageRules.keywords); _i < _Object$entries.length; _i++) {
        var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
          category = _Object$entries$_i[0],
          keywords = _Object$entries$_i[1];
        if (keywords.includes(token)) {
          return "keyword-".concat(category);
        }
      }
    }
    if ((_languageRules$operat = languageRules.operators) !== null && _languageRules$operat !== undefined && _languageRules$operat.includes(token)) {
      return "operator";
    }
    if (languageRules.numbers && new RegExp(languageRules.numbers).test(token)) {
      return "number";
    }
    if ((_languageRules$string = languageRules.strings) !== null && _languageRules$string !== undefined && _languageRules$string.delimiters.some(function (d) {
      return token.startsWith(d);
    })) {
      return "string";
    }
    if (token.startsWith(((_languageRules$commen = languageRules.comments) === null || _languageRules$commen === undefined ? undefined : _languageRules$commen.singleLine) || "") || (_languageRules$commen2 = languageRules.comments) !== null && _languageRules$commen2 !== undefined && _languageRules$commen2.multiLine && token.startsWith(languageRules.comments.multiLine[0]) && token.endsWith(languageRules.comments.multiLine[1])) {
      return "comment";
    }
    return "identifier";
  };
  var highlightCode = function highlightCode(code) {
    var tokens = tokenize(code);
    return tokens.map(function (token, index) {
      var type = getTokenType(token);
      var tokenClassName = sheet["token-".concat(type)] || sheet.token;
      return /*#__PURE__*/React.createElement("span", {
        key: index,
        className: tokenClassName
      }, token === "\t" ? /*#__PURE__*/React.createElement("span", {
        style: {
          marginLeft: "1em"
        }
      }) : token);
    });
  };
  return /*#__PURE__*/React.createElement("pre", {
    className: "".concat(sheet.syntaxHighlighter, " ").concat(sheet[theme])
  }, /*#__PURE__*/React.createElement("code", null, highlightCode(code)));
};

exports.SyntaxHighlighter = SyntaxHighlighter;
